polyfemos.front.sohplot.outfilefields — polyfemos 0.3.29 documentation

# polyfemos.front.sohplot.outfilefields

Type structure for ‘*.stf’ file header fields and data rows, and for ‘*.alert’ and ‘*.csv’ file data rows.

copyright

  2019, University of Oulu, Sodankyla Geophysical Observatory

license

  GNU Lesser General Public License v3.0 or later (https://spdx.org/licenses/LGPL-3.0-or-later.html)

Public Functions

`polyfemos.front.sohplot.outfilefields.` `alert`(inputstr)
  Parameters

    inputstr (str) –

  Return type

    str

  Returns

    Returns `None` if given `inputstr` didn’t contain valid alert information.

`polyfemos.front.sohplot.outfilefields.` `floatlist`(inputstr, length=2)
  Parameters

    - inputstr (str) – a string passed to `floatlist()`

    - length (int, optional) – if the formed list does not match the given `length`, `None` is returned.

  Return type

    list

  Returns

    list of floats or `None`, if formation of list was not possible with given `inputstr`

`polyfemos.front.sohplot.outfilefields.` `string`(inputstr)
  Parameters

    inputstr (str) – string passed to `str_()`

  Return type

    str

  Returns

    If `inputstr` is empty, `None` is returned.